@@ -179,55 +179,46 @@ print_help (void)
 {
   /* TRANSLATORS: --help output, GNU poke synopsis.
      no-wrap */
-  pk_puts (_("\
-Usage: poke [OPTION]... [FILE]\n"));
+  pk_puts (_("Usage: poke [OPTION]... [FILE]\n"));
 
   /* TRANSLATORS: --help output, GNU poke summary.
      no-wrap */
-  pk_puts (_("\
-Interactive editor for binary files.\n"));
+  pk_puts (_("Interactive editor for binary files.\n"));
 
   pk_puts ("\n");
   /* TRANSLATORS: --help output, GNU poke arguments.
      no-wrap */
-  pk_puts (_("\
-  -l, --load=FILE                     load the given pickle at startup.\n\
-  -L FILE                             load the given pickle and exit.\n"));
+  pk_puts (_("  -l, --load=FILE                     load the given pickle at startup\n"));
+  pk_puts (_("  -L FILE                             load the given pickle and exit\n"));
 
   pk_puts ("\n");
 
   /* TRANSLATORS: --help output, GNU poke arguments.
      no-wrap */
-  pk_puts (_("\
-Commanding poke from the command line:\n\
-  -c, --command=CMD                   execute the given command.\n\
-  -s, --source=FILE                   execute commands from FILE.\n"));
+  pk_puts (_("Commanding poke from the command line:\n"));
+  pk_puts (_("  -c, --command=CMD                   execute the given command\n"));
+  pk_puts (_("  -s, --source=FILE                   execute commands from FILE\n"));
 
   pk_puts ("\n");
-  pk_puts (_("\
-Styling text output:\n\
-      --color=(yes|no|auto|html|test) emit styled output.\n\
-      --style=STYLE_FILE              style file to use when styling.\n"));
+  pk_puts (_("Styling text output:\n"));
+  pk_puts (_("      --color=(yes|no|auto|html|test) emit styled output\n"));
+  pk_puts (_("      --style=STYLE_FILE              style file to use when styling\n"));
 
   pk_puts ("\n");
-  pk_puts (_("\
-Machine interface:\n\
-      --mi                            use the MI in stdin/stdout.\n"));
+  pk_puts (_("Machine interface:\n"));
+  pk_puts (_("      --mi                            use the MI in stdin/stdout\n"));
 
   pk_puts ("\n");
   /* TRANSLATORS: --help output, less used GNU poke arguments.
      no-wrap */
-  pk_puts (_("\
-  -q, --no-init-file                  do not load an init file.\n\
-      --no-auto-map                   disable auto-map.\n"));
+  pk_puts (_("  -q, --no-init-file                  do not load an init file\n"));
+  pk_puts (_("      --no-auto-map                   disable auto-map\n"));
 #if HAVE_HSERVER
-  pk_puts ("\
-      --no-hserver                    do not run the hyperlinks server.\n");
+  pk_puts (_("      --no-hserver                    do not run the hyperlinks server\n"));
 #endif
-  pk_puts (_("\
-      --quiet                         be as terse as possible.\n\
-      --help                          print a help message and exit.\n\
-      --version                       show version and exit.\n"));
+  pk_puts (_("      --quiet                         be as terse as possible\n"));
+  pk_puts (_("      --help                          print a help message and exit\n"));
+  pk_puts (_("      --version                       show version and exit\n"));
 
   pk_puts ("\n");
   /* TRANSLATORS: --help output 5+ (reports)
@@ -248,18 +239,21 @@ Report bugs in the bug tracker at\n\
 }
 
 void
-pk_print_version (void)
+pk_print_version (int hand_p)
 {
-  pk_term_class ("logo");
-  pk_puts ("     _____\n");
-  pk_puts (" ---'   __\\_______\n");
-  pk_printf ("            ______)  GNU poke %s\n", VERSION);
-  pk_puts ("            __)\n");
-  pk_puts ("           __)\n");
-  pk_puts (" ---._______)\n");
-  pk_term_end_class ("logo");
-  /* xgettext: no-wrap */
-  pk_puts ("\n");
+  if (hand_p)
+    {
+      pk_term_class ("logo");
+      pk_puts ("     _____\n");
+      pk_puts (" ---'   __\\_______\n");
+      pk_printf ("            ______)  GNU poke %s\n", VERSION);
+      pk_puts ("            __)\n");
+      pk_puts ("           __)\n");
+      pk_puts (" ---._______)\n");
+      pk_term_end_class ("logo");
+      /* xgettext: no-wrap */
+      pk_puts ("\n");
+    }
 
   /* It is important to separate the year from the rest of the message,
      as done here, to avoid having to retranslate the message when a new
@@ -413,7 +407,7 @@ parse_args_2 (int argc, char *argv[])
           goto exit_success;
           break;
         case VERSION_ARG:
-          pk_print_version ();
+          pk_print_version (0 /* hand_p */);
           goto exit_success;
           break;
         case QUIET_ARG:
